4. Available modules — Django Chuck 0.1 documentation

### Navigation

- index
- next |
- previous |
- Django Chuck 0.1 documentation »

# 4. Available modules

A brief description of all modules included in Django Chuck.

Please note that this is only a minimum set of modules for the most basic tasks. More apps are available through additional module repositories.

Module | Description
--- | ---
apache | Generates virtualhost for Apache and a mod_wsgi config
coffee-script | Installs the CoffeeScript binary into your virtualenv and adds its path to the django-compressor precompilers setting.
contact | A simple contact form app
core | Installs Django an the basic project structure
django-1.3 | Installs Django 1.3 (django-sekizai, a requirement of the cms module, doesnt work with Django 1.4 yet)
django-cms | Installs Django-Cms and filer apps
django-cms-search | Haystack search engine for Django-Cms
django-compressor | Compresses linked and inline JavaScript or CSS into single cached files.
django-debug-toolbar | The Django debug toolbar
django-extensions | Common Django extensions like shell`plus
django-imagekit | Automated image processing for Django models.
django-mptt | Build tree-based models
django-tastypie | Creating delicious REST APIs
django-tastypie-mongoengine | MongoEngine support for django-tastypie.
fabric | Fabric is a simple, Pythonic tool for remote execution and deployment.
feincms | Installs the FeinCMS
html5lib | Python library for working with HTML5 documents
jenkins | Plug and play integration with the Jenkins Coninuous Integration server
jquery | Installs the jQuery javascript library
lazyemailuser | Based on django-lazysignup to collect data with an temp user and convert it to a real user with username based on email address
less-css | The dynamic stylesheet language less-css.
mongoengine | A Python Document-Object Mapper for working with MongoDB
mootools | Install the Mootools javascript library
multilang | Multiple language support
mysql | MySQL database settings
nginx | Generates NGiNX virtualhost config
oracle | Oracle database settings
pil | The Python Image Library
postgres | PostgreSQL database settings
south | The defacto standard for database migrations
survey | Installs django-crowdsourcing <http://pypi.python.org/pypi/django-crowdsourcing/1.1.31>
tellafriend | Send link to current site in an email to tell a friend about it
twitter-bootstrap |
unittest | Some wicked, cool unit testing tools
uwsgi | Generates a config and app file for your uWSGI deployment

# 5. Additional module repositories

Currently their is only the extra repository from Notch Interactive available on Github. Feel free to send an email to chuck@notch-interactive.com if you want to add your Chuck module repository to this list.

To add another module repository you have to download it to a local folder and define the `module_basedirs` variable in your config file `~/.django_chuck_conf.py`.

    module_basedirs="/some/dir/to/additionial-modules","."

### Navigation

- index
- next |
- previous |
- Django Chuck 0.1 documentation »